PCB Environment: dsn::Data Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Data Fields
dsn::Data Struct Reference

## Public Member Functions
std::string | str () const
void | renamePinsWithSharedNames ()
void | inferMissingNetWidths ()
void | printNetWidths () const

## Static Public Member Functions
static bool | parseDSN (dsn::Data &, const std::string &)
static bool | parseJSON (dsn::Data &, const std::string &)
static bool | parseKiCAD (dsn::Data &, const std::string &)

## Data Fields
dsn::PCB | pcb
dsn::Structure | structure
std::map< std::string, dsn::Image > | images
std::map< std::string, dsn::Padstack > | padstacks
std::map< std::string, dsn::Net > | nets
std::vector< dsn::Placement > | placements

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp